==> nextcloud-24.0.10.tgz: nextcloud/apps/federation/l10n/de.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Der Liste der vertrauenswürdigen Server hinzugefügt",
    "Server is already in the list of trusted servers." : "Server ist bereits in der Liste der vertrauenswürdigen Server.",
    "No server to federate with found" : "Es wurde kein Server zum Verbinden per Federation gefunden",
    "Could not add server" : "Konnte Server nicht hinzufügen",
    "Trusted servers" : "Vertrauenswürdige Server",
    "Federation" : "Federation",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federation ermöglicht die Verbindung mit anderen vertrauenswürdigen Servern um das Nutzerverzeichnis auszutauschen.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federation erlaubt es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Benutzerverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Benutzernamen beim Federated-Sharing verwendet.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federation ermöglicht es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Benutzerverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Benutzernamen beim Federated-Sharing verwendet. Es ist nicht erforderlich, einen Server als vertrauenswürdig hinzuzufügen, um eine \"federated\" Freigabe zu erstellen.",
    "+ Add trusted server" : "+ Vertrauenswürdigen Server hinzufügen",
    "Trusted server" : "Vertrauenswürdiger Server",
    "Add" : "Hinzufügen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/federation/l10n/de.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Der Liste der vertrauenswürdigen Server hinzugefügt",
    "Server is already in the list of trusted servers." : "Server ist bereits in der Liste der vertrauenswürdigen Server.",
    "No server to federate with found" : "Es wurde kein Server zum Verbinden per Federation gefunden",
    "Could not add server" : "Konnte Server nicht hinzufügen",
    "Trusted servers" : "Vertrauenswürdige Server",
    "Federation" : "Federation",
    "+ Add trusted server" : "+ Vertrauenswürdigen Server hinzufügen",
    "Trusted server" : "Vertrauenswürdiger Server",
    "Add" : "Hinzufügen",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federation ermöglicht die Verbindung mit anderen vertrauenswürdigen Servern um das Nutzerverzeichnis auszutauschen.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federation erlaubt es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Benutzerverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Benutzernamen beim Federated-Sharing verwendet.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federation ermöglicht es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Benutzerverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Benutzernamen beim Federated-Sharing verwendet. Es ist nicht erforderlich, einen Server als vertrauenswürdig hinzuzufügen, um eine \"federated\" Freigabe zu erstellen."
},
"nplurals=2; plural=(n != 1);");
